Header menu logo FsCheck

Arbitrary<'T> Type

Constructors

Constructor Description

Arbitrary()

Full Usage: Arbitrary()

Returns: Arbitrary<'T>
Returns: Arbitrary<'T>

Instance members

Instance member Description

this.Generator

Full Usage: this.Generator

Returns: Gen<'T>
Modifiers: abstract

Returns a generator for 'a.

Returns: Gen<'T>

this.Shrinker

Full Usage: this.Shrinker

Parameters:
    arg0 : 'T

Returns: 'T seq
Modifiers: abstract

Returns a sequence of the immediate shrinks of the given value. The immediate shrinks should not include doubles or the given value itself. The default implementation returns the empty sequence (i.e. no shrinking).

arg0 : 'T
Returns: 'T seq

Type something to start searching.