Header menu logo FsCheck

Config Type

For configuring a run.

Instance members

Instance member Description

this.ArbMap

Full Usage: this.ArbMap

Returns: IArbMap
Returns: IArbMap

this.EndSize

Full Usage: this.EndSize

Returns: int

The size to use for the last test, when all the tests are passing. The size increases linearly between Start- and EndSize.

Returns: int

this.Every

Full Usage: this.Every

Returns: int -> obj list -> string

What to print when new arguments args are generated in test n

Returns: int -> obj list -> string

this.EveryShrink

Full Usage: this.EveryShrink

Returns: obj list -> string

What to print every time a counter-example is successfully shrunk

Returns: obj list -> string

this.MaxRejected

Full Usage: this.MaxRejected

Returns: int

The maximum number of tests where values are rejected, e.g. as the result of ==>

Returns: int

this.MaxTest

Full Usage: this.MaxTest

Returns: int

The maximum number of tests that are run.

Returns: int

this.Name

Full Usage: this.Name

Returns: string

Name of the test.

Returns: string

this.ParallelRunConfig

Full Usage: this.ParallelRunConfig

Returns: ParallelRunConfig option

If set, inputs for property generation and property evaluation will be run in parallel.

Returns: ParallelRunConfig option

this.QuietOnSuccess

Full Usage: this.QuietOnSuccess

Returns: bool

If set, suppresses the output from the test if the test is successful.

Returns: bool

this.Replay

Full Usage: this.Replay

Returns: Replay option

If set, the seed to use to start testing. Allows reproduction of previous runs.

Returns: Replay option

this.Runner

Full Usage: this.Runner

Returns: IRunner

A custom test runner, e.g. to integrate with a test framework like xUnit or NUnit.

Returns: IRunner

this.StartSize

Full Usage: this.StartSize

Returns: int

The size to use for the first test.

Returns: int

this.WithArbitrary

Full Usage: this.WithArbitrary

Parameters:
    arbitrary : 'a seq

Returns: Config

Returns a new Config with specified Arbitrary

arbitrary : 'a seq
Returns: Config

this.WithEndSize

Full Usage: this.WithEndSize

Parameters:
    endSize : int

Returns: Config

Returns a new Config with specified EndSize

endSize : int
Returns: Config

this.WithEvery

Full Usage: this.WithEvery

Parameters:
    every : int -> obj list -> string

Returns: Config

Returns a new Config with specified Every function

every : int -> obj list -> string
Returns: Config

this.WithEveryShrink

Full Usage: this.WithEveryShrink

Parameters:
    everyShrink : obj list -> string

Returns: Config

Returns a new Config with specified EveryShrink function

everyShrink : obj list -> string
Returns: Config

this.WithMaxRejected

Full Usage: this.WithMaxRejected

Parameters:
    maxRejected : int

Returns: Config

Returns a new Config with specified MaxRejected

maxRejected : int
Returns: Config

this.WithMaxTest

Full Usage: this.WithMaxTest

Parameters:
    maxTest : int

Returns: Config

Returns a new Config with specified MaxTest

maxTest : int
Returns: Config

this.WithName

Full Usage: this.WithName

Parameters:
    name : string

Returns: Config

Returns a new Config with specified Name

name : string
Returns: Config

this.WithParallelRunConfig

Full Usage: this.WithParallelRunConfig

Parameters:
Returns: Config

Returns a new Config with specified ParallelRunConfig

config : ParallelRunConfig option
Returns: Config

this.WithQuietOnSuccess

Full Usage: this.WithQuietOnSuccess

Parameters:
    quietOnSuccess : bool

Returns: Config

Returns a new Config with specified QuietOnSuccess

quietOnSuccess : bool
Returns: Config

this.WithReplay

Full Usage: this.WithReplay

Parameters:
Returns: Config

Returns a new Config with specified Replay option

replay : Replay option
Returns: Config

this.WithRunner

Full Usage: this.WithRunner

Parameters:
Returns: Config

Returns a new Config with specified Runner

runner : IRunner
Returns: Config

this.WithStartSize

Full Usage: this.WithStartSize

Parameters:
    startSize : int

Returns: Config

Returns a new Config with specified StartSize

startSize : int
Returns: Config

Static members

Static member Description

Config.Default

Full Usage: Config.Default

Returns: Config

The default configuration is the quick configuration.

Returns: Config

Config.Quick

Full Usage: Config.Quick

Returns: Config

The quick configuration only prints a summary result at the end of the test.

Returns: Config

Config.QuickThrowOnFailure

Full Usage: Config.QuickThrowOnFailure

Returns: Config

Like the Quick configuration, only throws an exception with the error message if the test fails or is exhausted. Useful for use within other unit testing frameworks that usually adopt this methodology to signal failure.

Returns: Config

Config.Verbose

Full Usage: Config.Verbose

Returns: Config

The verbose configuration prints each generated argument.

Returns: Config

Config.VerboseThrowOnFailure

Full Usage: Config.VerboseThrowOnFailure

Returns: Config

Like the Verbose configuration, only throws an exception with the error message if the test fails or is exhausted. Useful for use within other unit testing frameworks that usually adopt this methodology to signal failure.

Returns: Config

Type something to start searching.