Machine<'Actual, 'Model> Type
Defines the initial state for actual and model object, and allows to define the generator to use for the next state, based on the model.
Constructors
| Constructor |
Description
|
|
|
Full Usage:
Machine(maxNumberOfCommands)
Parameters:
int
Returns: Machine<'Actual, 'Model>
|
|
Instance members
| Instance member |
Description
|
Full Usage:
this.MaxNumberOfCommands
Returns: int
|
|
|
|
|
|
|
|
FsCheck