Header menu logo FsCheck

Operation<'Actual, 'Model> Type

An operation describes pre and post conditions and the model for a single operation under test. The post-conditions are the invariants that will be checked; when these do not hold the test fails.

Constructors

Constructor Description

Operation()

Full Usage: Operation()

Returns: Operation<'Actual, 'Model>
Returns: Operation<'Actual, 'Model>

Instance members

Instance member Description

this.Check

Full Usage: this.Check

Parameters:
    arg0 : 'Actual
    arg1 : 'Model

Returns: Property
Modifiers: abstract

Executes the command on the object under test, and returns a property that must hold. This property typically compares the state of the model with the state of the object after execution of the command.

arg0 : 'Actual
arg1 : 'Model
Returns: Property

this.Pre

Full Usage: this.Pre

Parameters:
    arg0 : 'Model

Returns: bool
Modifiers: abstract

Optional precondition for execution of the command. When this does not hold, the test continues but the command is not executed.

arg0 : 'Model
Returns: bool

this.Run

Full Usage: this.Run

Parameters:
    arg0 : 'Model

Returns: 'Model
Modifiers: abstract

Executes the command on the model of the object.

arg0 : 'Model
Returns: 'Model

Type something to start searching.