Header menu logo FsCheck

Setup<'Actual, 'Model> Type

Constructors

Constructor Description

Setup()

Full Usage: Setup()

Returns: Setup<'Actual, 'Model>
Returns: Setup<'Actual, 'Model>

Instance members

Instance member Description

this.Actual

Full Usage: this.Actual

Returns: 'Actual
Modifiers: abstract

Randomly generate the initial state of the actual object. Should still correspond to the initial state of model object; so you should only randomly generate parameters to the instance that don't affect the model. Note:make sure that each value is truly a new instance if the commands change the state of the object. Gen.connstant in particular is a bad idea - use Gen.fresh instead.

Returns: 'Actual

this.Model

Full Usage: this.Model

Returns: 'Model
Modifiers: abstract

Initial state of model object. Must correspond to initial state of actual object.

Returns: 'Model

Type something to start searching.