Gen Type
Table of contents
Other module members
Static members
| Static member |
Description
|
||
|
|||
|
|||
|
|||
|
|||
|
|||
|
|||
|
|||
|
Build a generator that randomly generates one of the values in the given non-empty array.
|
||
|
Build a generator that randomly generates one of the values in the given non-empty, finite sequence.
|
||
|
|||
|
Build a generator that generates a value from one of the generators in the given non-empty arrat, with given probabilities. The sum of the probabilities must be larger than zero.
|
||
|
Build a generator that generates a value from one of the generators in the given non-empty seq, with given probabilities. The sum of the probabilities must be larger than zero.
|
||
|
|||
|
Build a generator that takes a non-empty array and randomly generates one of the values among an initial segment of that array. The size of this initial segment increases with the size parameter. Essentially this generator is Gen.Elements but taking also the size into account.
|
||
|
Build a generator that takes a non-empty sequence and randomly generates one of the values among an initial segment of that sequence. The size of this initial segment increases with the size parameter. Essentially this generator is Gen.Elements but taking also the size into account.
|
||
|
|||
|
|||
|
|||
|
|||
|
|||
|
|||
|
|||
|
Generates random arrays of given length where the sum of all elements equals the given sum.
|
||
|
|||
|
|||
Full Usage:
Gen.Sample(generator, numberOfSamples, size)
Parameters:
Gen<'T>
numberOfSamples : int
size : int
Returns: 'T[]
|
Generates numberOfSample values with the given size.
|
||
Full Usage:
Gen.Sample(generator, numberOfSamples)
Parameters:
Gen<'T>
numberOfSamples : int
Returns: 'T[]
|
Generates numberOfSample values with a new seed and size 50.
|
||
|
|||
|
|||
Creates a new generator that generates values from the source generator, applies the selector to them to get a new generator, and generates values by applying the resultSelector to the source value and the value from the second generator.
|
|||
|
|||
|
|||
|
|||
|
|||
|
|||
|
|||
|
|||
|
|||
|
|||
|
|||
|
Create generators from generators
Static members
| Static member |
Description
|
|
|
|
|
|
|
|
|
|
Transform the given sequence into a generator of sequences using the given function to create a generator for each element of the sequence. Each sequence generated by the resulting generator can be infinite, if the source sequence is infinite. [category: Create generators from generators]
|
|
FsCheck