Prop Type
Extensions to construct Properties.
Static members
| Static member |
Description
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Construct a property that succeeds if both succeed. (cfr 'and')
|
|
|
|
|
|
|
Full Usage:
Prop.Classify(property, cond, name)
Parameters:
bool
cond : bool
name : string
Returns: Property
|
Classify test cases. Test cases satisfying the condition are assigned the classification given.
|
|
|
|
|
|
|
Full Usage:
Prop.Collect(property, v)
Parameters:
bool
v : 'CollectedValue
Returns: Property
|
Collect data values. The argument of collect is evaluated in each test case, and the distribution of values is reported.
|
|
|
Full Usage:
Prop.Discard()
Returns: 'a
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
Prop.Implies(condition, property)
Parameters:
bool
property : bool
Returns: Property
|
Conditional property combinator. Resulting property holds if the property holds when the condition does.
|
|
|
|
|
Full Usage:
Prop.Label(property, label)
Parameters:
bool
label : string
Returns: Property
|
Add the given label to the property. The labels of a failing sub-property are displayed when it fails.
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
Prop.Trivial(property, condition)
Parameters:
bool
condition : bool
Returns: Property
|
Count trivial cases. Test cases for which the condition is True are classified as trivial.
|
|
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
Prop.When(property, condition)
Parameters:
bool
condition : bool
Returns: Property
|
Conditional property combinator. Resulting property holds if the property holds when the condition does.
|
FsCheck