ArbMap Module
Functions and values
| Function or value |
Description
|
|
|
|
The immutable default mapping from a type to Arbitrary for that type.
|
|
|
|
|
|
|
|
|
|
|
|
Return a new Type to Arbitrary map that merges the existing map with new Arbitrary<'T> instances
discovered on the given type argument 'TArb.
The new Arbitrary instances take precedence over the ones for the same type
in the existing map.
instancesType should have static methods or properties that return Arbitrary<'T>
instances. The methods or properties can have any name, and there can be any number of them.
A method may return Arbitrary instances for generic types, e.g. Arbitrary
|
|
FsCheck