Prop Module
Combinators to build properties, which define the property to be tested, with some convenience methods to investigate the generated arguments and any found counter-examples.
Functions and values
| Function or value |
Description
|
|
Classify test cases. Test cases satisfying the condition are assigned the classification given.
|
|
Collect data values. The argument of collect is evaluated in each test case, and the distribution of values is reported, using sprintf "%A".
|
Full Usage:
Prop.discard ()
Parameters:
unit
Returns: 'a
|
|
Full Usage:
Prop.filter condition assertion
Parameters:
bool
assertion : 'Testable
Returns: Property
|
Conditional property combinator. Resulting property holds if the given property holds whenever the condition does. See also operator: 'assertion ==> property'
|
|
|
Full Usage:
Prop.given condition (iftrue, ifFalse)
Parameters:
bool
iftrue : 'TestableIfTrue
ifFalse : 'TestableIfFalse
Returns: Property
|
Depending on the condition, return the first testable if true and the second if false.
|
|
Add the given label to the property. The labels of a failing sub-property are displayed when it fails.
|
|
Turns a testable type into a property. Testables are unit, Boolean, Lazy testables, Gen testables, Async testables, Task testables, and functions from a type for which a generator is known to a testable.
|
|
|
|
Count trivial cases. Test cases for which the condition is True are classified as trivial.
|
FsCheck