Header menu logo FsCheck

IRunner Type

For implementing your own test runner.

Instance members

Instance member Description

this.OnArguments

Full Usage: this.OnArguments

Parameters:
    arg0 : int
    arg1 : obj list
    arg2 : int -> obj list -> string

Modifiers: abstract

Called whenever arguments are generated and after the test is run.

arg0 : int
arg1 : obj list
arg2 : int -> obj list -> string

this.OnFinished

Full Usage: this.OnFinished

Parameters:
Modifiers: abstract

Called whenever all tests are done, either Passed, Failed or Exhausted.

arg0 : string
arg1 : TestResult

this.OnShrink

Full Usage: this.OnShrink

Parameters:
    arg0 : obj list
    arg1 : obj list -> string

Modifiers: abstract

Called on a successful shrink.

arg0 : obj list
arg1 : obj list -> string

this.OnStartFixture

Full Usage: this.OnStartFixture

Parameters:
Modifiers: abstract

Called before a group of properties on a type are checked.

arg0 : Type

Type something to start searching.