Header menu logo FsCheck

NonEmptyString Type

Represents a string that is not null or empty, and does not contain any null characters ('\000')

Union cases

Union case Description

NonEmptyString string

Full Usage: NonEmptyString string

Parameters:
    Item : string

Item : string

Instance members

Instance member Description

this.Get

Full Usage: this.Get

Returns: string
Returns: string

Type something to start searching.