PropertyAttribute Type
Run this method as an FsCheck test.
Constructors
| Constructor |
Description
|
|
|
Instance members
| Instance member |
Description
|
Full Usage:
this.Arbitrary
|
The Arbitrary instances to use for this test method. The Arbitrary instances are merged in back to front order i.e. instances for the same generated type at the front of the array will override those at the back. |
Full Usage:
this.EndSize
|
The size to use for the last test, when all the tests are passing. The size increases linearly between Start- and EndSize. |
Full Usage:
this.MaxFail
|
The maximum number of tests where values are rejected, e.g. as the result of ==> |
Full Usage:
this.MaxTest
|
The maximum number of tests that are run. |
Full Usage:
this.Parallelism
|
If set, run tests in parallel. Useful for Task/async related work and heavy number crunching Environment.ProcessorCount have been found to be useful default. |
Full Usage:
this.QuietOnSuccess
|
If set, suppresses the output from the test if the test is successful. This can be useful when running tests with TestDriven.net, because TestDriven.net pops up the Output window in Visual Studio if a test fails; thus, when conditioned to that behaviour, it's always a bit jarring to receive output from passing tests. The default is false, which means that FsCheck will also output test results on success, but if set to true, FsCheck will suppress output in the case of a passing test. This setting doesn't affect the behaviour in case of test failures. |
Full Usage:
this.Replay
|
If set, the seed to use to start testing. Allows reproduction of previous runs. You can just paste the tuple from the output window, e.g. 12344,12312 or (123,123). |
Full Usage:
this.StartSize
|
The size to use for the first test. |
Full Usage:
this.Verbose
|
Output all generated arguments. |
FsCheck