Rnd Type
Record fields
| Record Field |
Description
|
Full Usage:
Gamma
Field type: uint64
|
An odd integer
|
Full Usage:
Seed
Field type: uint64
|
Seed value for the random number generator.
|
Constructors
| Constructor |
Description
|
Create a new Rnd value with the specified seed value and the 'golden' gamma.
|
|
|
Create a new random number generator with the given seed and gamma. Useful to faithfully reproduce a sequence or part of it. gamma must be odd, or this throws invalid argument exception. For good pseudo-random properties, please only use seeds and gamma that were generated as part of a sequence started with the default create function.
|
FsCheck