Runner Module
Functions and values
| Function or value |
Description
|
Full Usage:
argumentsToString args
Parameters:
'a list
Returns: string
|
|
|
A runner that prints results to the standard output.
|
Full Usage:
onArgumentsToString n args
Parameters:
int
args : 'a list
Returns: string
|
|
Full Usage:
onFinishedToString name testResult
Parameters:
string
testResult : TestResult
Returns: string
|
A function that returns the default string that is printed as a result of the test.
|
Full Usage:
onShrinkToString args
Parameters:
'a list
Returns: string
|
|
|
|
|
FsCheck