Header menu logo FsCheck

TestResult Type

Union cases

Union case Description

Exhausted TestData

Full Usage: Exhausted TestData

Parameters:
Item : TestData

Failed(TestData, obj list, obj list, Outcome, Rnd, Rnd, int)

Full Usage: Failed(TestData, obj list, obj list, Outcome, Rnd, Rnd, int)

Parameters:
Item1 : TestData
Item2 : obj list
Item3 : obj list
Item4 : Outcome
Item5 : Rnd
Item6 : Rnd
Item7 : int

Passed(TestData, bool)

Full Usage: Passed(TestData, bool)

Parameters:
Item1 : TestData
Item2 : bool

Instance members

Instance member Description

this.IsExhausted

Full Usage: this.IsExhausted

Returns: bool
Returns: bool

this.IsFailed

Full Usage: this.IsFailed

Returns: bool
Returns: bool

this.IsPassed

Full Usage: this.IsPassed

Returns: bool
Returns: bool

Type something to start searching.