Header menu logo FsCheck

FsCheck.Xunit Namespace

Type Description

CheckExtensions (Type)

CheckExtensions (Type)

PropertiesAttribute (Type)

Set common configuration for all properties within this class or module

PropertiesAttribute (Type)

Set common configuration for all properties within this class or module

PropertyAttribute (Type)

Run this method as an FsCheck test.

PropertyAttribute (Type)

Run this method as an FsCheck test.

PropertyDiscoverer (Type)

xUnit2 test case discoverer to link the method with the PropertyAttribute to the PropertyTestCase so the test can be run via FsCheck.

PropertyDiscoverer (Type)

xUnit.v3 test case discoverer to link the method with the PropertyAttribute to the PropertyTestCase so the test can be run via FsCheck.

PropertyFailedException (Type)

PropertyFailedException (Type)

PropertyTestCase (Type)

The xUnit2 test runner for the PropertyAttribute that executes the test via FsCheck

PropertyTestCase (Type)

The xUnit.v3 test runner for the PropertyAttribute that executes the test via FsCheck

TestOutputRunner (Type)

A runner for FsCheck (i.e. that you can use as Config.Runner) which outputs to Xunit's given ITestOutputHelper. For example, { Config.QuickThrowOnFailure with Runner = TestOutputRunner(output) }

TestOutputRunner (Type)

A runner for FsCheck (i.e. that you can use as Config.Runner) which outputs to Xunit's given ITestOutputHelper. For example, { Config.QuickThrowOnFailure with Runner = TestOutputRunner(output) }

XunitRunner (Type)

XunitRunner (Type)

Type something to start searching.