Header menu logo FsCheck

PropertyAttribute Type

Run this method as an FsCheck test.

Constructors

Constructor Description

PropertyAttribute()

Full Usage: PropertyAttribute()

Returns: PropertyAttribute

Instance members

Instance member Description

this.Arbitrary

Full Usage: this.Arbitrary

The Arbitrary instances to use for this test method. The Arbitrary instances are merged in back to front order i.e. instances for the same generated type at the front of the array will override those at the back.

this.EndSize

Full Usage: this.EndSize

The size to use for the last test, when all the tests are passing. The size increases linearly between Start- and EndSize.

this.MaxRejected

Full Usage: this.MaxRejected

The maximum number of tests where values are rejected, e.g. as the result of ==>

this.MaxTest

Full Usage: this.MaxTest

The maximum number of tests that are run.

this.Parallelism

Full Usage: this.Parallelism

If set, run tests in parallel. Useful for Task/async related work and heavy number crunching Environment.ProcessorCount have been found to be useful default.

this.QuietOnSuccess

Full Usage: this.QuietOnSuccess

If set, suppresses the output from the test if the test is successful. This can be useful when running tests with TestDriven.net, because TestDriven.net pops up the Output window in Visual Studio if a test fails; thus, when conditioned to that behaviour, it's always a bit jarring to receive output from passing tests. The default is false, which means that FsCheck will also output test results on success, but if set to true, FsCheck will suppress output in the case of a passing test. This setting doesn't affect the behaviour in case of test failures.

this.Replay

Full Usage: this.Replay

If set, the seed to use to start testing. Allows reproduction of previous runs. You can just paste the tuple from the output window, e.g. 12344,12312 or (123,123). Additionally, you can also specify a start size as the third parameter, e.g. 12344,12312,10 or (123,123,10).

this.StartSize

Full Usage: this.StartSize

The size to use for the first test.

this.Verbose

Full Usage: this.Verbose

Output all generated arguments.

Type something to start searching.