PropertyDiscoverer Type
xUnit2 test case discoverer to link the method with the PropertyAttribute to the PropertyTestCase so the test can be run via FsCheck.
Constructors
| Constructor |
Description
|
|
|
Full Usage:
PropertyDiscoverer(messageSink)
Parameters:
IMessageSink
Returns: PropertyDiscoverer
|
|
Instance members
| Instance member |
Description
|
|
|
FsCheck