Arbitrary<'T> Type
Constructors
| Constructor |
Description
|
|
|
Instance members
| Instance member |
Description
|
|
Returns a generator for 'a.
|
Full Usage:
this.Shrinker
Parameters:
'T
Returns: 'T seq
Modifiers: abstract |
Returns a sequence of the immediate shrinks of the given value. The immediate shrinks should not include doubles or the given value itself. The default implementation returns the empty sequence (i.e. no shrinking).
|
FsCheck