Config Type
For configuring a run.
Instance members
| Instance member |
Description
|
|
|
Full Usage:
this.EndSize
Returns: int
|
The size to use for the last test, when all the tests are passing. The size increases linearly between Start- and EndSize.
|
Full Usage:
this.Every
Returns: int -> obj list -> string
|
What to print when new arguments args are generated in test n
|
Full Usage:
this.EveryShrink
Returns: obj list -> string
|
What to print every time a counter-example is successfully shrunk
|
Full Usage:
this.MaxRejected
Returns: int
|
The maximum number of tests where values are rejected, e.g. as the result of ==>
|
Full Usage:
this.MaxTest
Returns: int
|
The maximum number of tests that are run.
|
Full Usage:
this.Name
Returns: string
|
Name of the test.
|
|
If set, inputs for property generation and property evaluation will be run in parallel.
|
Full Usage:
this.QuietOnSuccess
Returns: bool
|
If set, suppresses the output from the test if the test is successful.
|
|
If set, the seed to use to start testing. Allows reproduction of previous runs.
|
|
A custom test runner, e.g. to integrate with a test framework like xUnit or NUnit.
|
Full Usage:
this.StartSize
Returns: int
|
The size to use for the first test.
|
|
|
|
|
|
Returns a new Config with specified Every function
|
|
Returns a new Config with specified EveryShrink function
|
|
|
|
|
|
|
Full Usage:
this.WithParallelRunConfig
Parameters:
ParallelRunConfig option
Returns: Config
|
Returns a new Config with specified ParallelRunConfig
|
|
|
|
|
|
|
|
Static members
| Static member |
Description
|
|
The default configuration is the quick configuration.
|
|
The quick configuration only prints a summary result at the end of the test.
|
|
Like the Quick configuration, only throws an exception with the error message if the test fails or is exhausted. Useful for use within other unit testing frameworks that usually adopt this methodology to signal failure.
|
|
The verbose configuration prints each generated argument.
|
|
Like the Verbose configuration, only throws an exception with the error message if the test fails or is exhausted. Useful for use within other unit testing frameworks that usually adopt this methodology to signal failure.
|
FsCheck