Setup<'Actual, 'Model> Type
Constructors
| Constructor |
Description
|
|
Instance members
| Instance member |
Description
|
Full Usage:
this.Actual
Returns: 'Actual
Modifiers: abstract |
Randomly generate the initial state of the actual object. Should still correspond to the initial state of model object; so you should only randomly generate parameters to the instance that don't affect the model. Note:make sure that each value is truly a new instance if the commands change the state of the object. Gen.connstant in particular is a bad idea - use Gen.fresh instead.
|
Full Usage:
this.Model
Returns: 'Model
Modifiers: abstract |
Initial state of model object. Must correspond to initial state of actual object.
|
FsCheck