IRunner Type
For implementing your own test runner.
Instance members
| Instance member |
Description
|
Full Usage:
this.OnArguments
Parameters:
int
arg1 : obj list
arg2 : int -> obj list -> string
Modifiers: abstract |
Called whenever arguments are generated and after the test is run.
|
|
Called whenever all tests are done, either Passed, Failed or Exhausted.
|
Full Usage:
this.OnShrink
Parameters:
obj list
arg1 : obj list -> string
Modifiers: abstract |
Called on a successful shrink.
|
|
Called before a group of properties on a type are checked.
|
FsCheck