NonEmptyString Type
Represents a string that is not null or empty, and does not contain any null characters ('\000')
Union cases
| Union case |
Description
|
Full Usage:
NonEmptyString string
Parameters:
string
|
|
Instance members
| Instance member |
Description
|
Full Usage:
this.Get
Returns: string
|
|
FsCheck