FsCheck.Xunit Namespace
| Type | Description |
|
|
|
|
|
|
|
Set common configuration for all properties within this class or module |
|
|
Set common configuration for all properties within this class or module |
|
|
Run this method as an FsCheck test. |
|
|
Run this method as an FsCheck test. |
|
|
xUnit2 test case discoverer to link the method with the PropertyAttribute to the PropertyTestCase so the test can be run via FsCheck. |
|
|
xUnit.v3 test case discoverer to link the method with the PropertyAttribute to the PropertyTestCase so the test can be run via FsCheck. |
|
|
|
|
|
|
|
|
The xUnit2 test runner for the PropertyAttribute that executes the test via FsCheck |
|
|
The xUnit.v3 test runner for the PropertyAttribute that executes the test via FsCheck |
|
|
A runner for FsCheck (i.e. that you can use as Config.Runner) which outputs to Xunit's given ITestOutputHelper. For example, { Config.QuickThrowOnFailure with Runner = TestOutputRunner(output) } |
|
|
A runner for FsCheck (i.e. that you can use as Config.Runner) which outputs to Xunit's given ITestOutputHelper. For example, { Config.QuickThrowOnFailure with Runner = TestOutputRunner(output) } |
|
|
|
|
|
|
FsCheck